# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTRefreshReleaseParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'workspace_id': 'str',
        'create_new': 'bool',
        'update_params': 'BTUpdateReleasePackageParams',
        'workflow_id': 'str'
    }

    attribute_map = {
        'workspace_id': 'workspaceId',
        'create_new': 'createNew',
        'update_params': 'updateParams',
        'workflow_id': 'workflowId'
    }

    def __init__(self, workspace_id=None, create_new=None, update_params=None, workflow_id=None):  # noqa: E501
        """BTRefreshReleaseParams - a model defined in OpenAPI"""  # noqa: E501

        self._workspace_id = None
        self._create_new = None
        self._update_params = None
        self._workflow_id = None
        self.discriminator = None

        if workspace_id is not None:
            self.workspace_id = workspace_id
        if create_new is not None:
            self.create_new = create_new
        if update_params is not None:
            self.update_params = update_params
        if workflow_id is not None:
            self.workflow_id = workflow_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTRefreshReleaseParams.  # noqa: E501


        :return: The workspace_id of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTRefreshReleaseParams.


        :param workspace_id: The workspace_id of this BTRefreshReleaseParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def create_new(self):
        """Gets the create_new of this BTRefreshReleaseParams.  # noqa: E501


        :return: The create_new of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: bool
        """
        return self._create_new

    @create_new.setter
    def create_new(self, create_new):
        """Sets the create_new of this BTRefreshReleaseParams.


        :param create_new: The create_new of this BTRefreshReleaseParams.  # noqa: E501
        :type: bool
        """

        self._create_new = create_new

    @property
    def update_params(self):
        """Gets the update_params of this BTRefreshReleaseParams.  # noqa: E501


        :return: The update_params of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: BTUpdateReleasePackageParams
        """
        return self._update_params

    @update_params.setter
    def update_params(self, update_params):
        """Sets the update_params of this BTRefreshReleaseParams.


        :param update_params: The update_params of this BTRefreshReleaseParams.  # noqa: E501
        :type: BTUpdateReleasePackageParams
        """

        self._update_params = update_params

    @property
    def workflow_id(self):
        """Gets the workflow_id of this BTRefreshReleaseParams.  # noqa: E501


        :return: The workflow_id of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this BTRefreshReleaseParams.


        :param workflow_id: The workflow_id of this BTRefreshReleaseParams.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTRefreshReleaseParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
