# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserEmailVerifyParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'request_id': 'str',
        'user_id': 'str',
        'email': 'str',
        'secret': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'user_id': 'userId',
        'email': 'email',
        'secret': 'secret'
    }

    def __init__(self, request_id=None, user_id=None, email=None, secret=None):  # noqa: E501
        """BTUserEmailVerifyParams - a model defined in OpenAPI"""  # noqa: E501

        self._request_id = None
        self._user_id = None
        self._email = None
        self._secret = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if user_id is not None:
            self.user_id = user_id
        if email is not None:
            self.email = email
        if secret is not None:
            self.secret = secret

    @property
    def request_id(self):
        """Gets the request_id of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The request_id of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this BTUserEmailVerifyParams.


        :param request_id: The request_id of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def user_id(self):
        """Gets the user_id of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The user_id of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTUserEmailVerifyParams.


        :param user_id: The user_id of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def email(self):
        """Gets the email of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The email of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTUserEmailVerifyParams.


        :param email: The email of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def secret(self):
        """Gets the secret of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The secret of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this BTUserEmailVerifyParams.


        :param secret: The secret of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._secret = secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserEmailVerifyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
